summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoParagLayout.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoParagLayout.h')
-rw-r--r--lib/kotext/KoParagLayout.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/lib/kotext/KoParagLayout.h b/lib/kotext/KoParagLayout.h
index 975fdaf0..2c9b9dea 100644
--- a/lib/kotext/KoParagLayout.h
+++ b/lib/kotext/KoParagLayout.h
@@ -40,7 +40,7 @@ class KOTEXT_EXPORT KoParagLayout
{
public:
KoParagLayout();
- KoParagLayout( const KoParagLayout &layout ) { operator=( layout ); }
+ KoParagLayout( const KoParagLayout &tqlayout ) { operator=( tqlayout ); }
~KoParagLayout();
@@ -96,7 +96,7 @@ public:
char pageBreaking; // Page breaking flags
char direction; // TQChar::Direction
/// Alignment flag (AlignAuto/AlignLeft/AlignRight/AlignJustify)
- char alignment; // TQt::AlignmentFlags
+ char tqalignment; // TQt::AlignmentFlags
KoBorder leftBorder, rightBorder, topBorder, bottomBorder;
/// The background color of the paragraph
@@ -122,39 +122,39 @@ public:
const KoTabulatorList& tabList() const { return m_tabList; }
//! Assignment operator for KoParagLayout
/** Copy a paragraph layout.
*
* If you're modifying this, you might also need to modify
* KoTextParag::setParagLayout
*/
void operator=( const KoParagLayout & );
- /** Return a set of flags showing the differences between this and 'layout' */
- int compare( const KoParagLayout & layout ) const;
+ /** Return a set of flags showing the differences between this and 'tqlayout' */
+ int compare( const KoParagLayout & tqlayout ) const;
- /** Save this parag layout to XML.
+ /** Save this parag tqlayout to XML.
* This format is used by KWord for paragraphs, and by KPresenter+KWord for styles.
*/
- void saveParagLayout( TQDomElement & parentElem, int alignment ) const;
+ void saveParagLayout( TQDomElement & parentElem, int tqalignment ) const;
- /** Load this parag layout from XML.
+ /** Load this parag tqlayout from XML.
* This format is used by KWord for paragraphs, and by KPresenter+KWord for styles.
*/
- static void loadParagLayout( KoParagLayout& layout, const TQDomElement& parentElem, int docVersion = 2 );
+ static void loadParagLayout( KoParagLayout& tqlayout, const TQDomElement& parentElem, int docVersion = 2 );
- /// Load this parag layout from Oasis XML
- static void loadOasisParagLayout( KoParagLayout& layout, KoOasisContext& context );
- /// Save this parag layout to Oasis XML
+ /// Load this parag tqlayout from Oasis XML
+ static void loadOasisParagLayout( KoParagLayout& tqlayout, KoOasisContext& context );
+ /// Save this parag tqlayout to Oasis XML
/// @param savingStyle true if this is saved as part of a user style,
/// false when saving a paragraph
/// @param gs the style where all the properties will be saved to
/// @param context the current context
void saveOasis( KoGenStyle& gs, KoSavingContext& context, bool savingStyle ) const;
/// Convert an alignment string into an alignment flag (load)
static TQt::AlignmentFlags loadOasisAlignment( const TQCString& str );
- /// Convert an alignment flag into an alignment string (save)
- static TQCString saveOasisAlignment( TQt::AlignmentFlags alignment );
+ /// Convert an tqalignment flag into an tqalignment string (save)
+ static TQCString saveOasisAlignment( TQt::AlignmentFlags tqalignment );
private:
static int getAttribute(const TQDomElement &element, const char *attributeName, int defaultValue) {
@@ -122,39 +122,39 @@ public:
const KoTabulatorList& tabList() const { return m_tabList; }
//! Assignment operator for KoParagLayout
- /** Copy a paragraph layout.
+ /** Copy a paragraph tqlayout.
*
* If you're modifying this, you might also need to modify
@@ -122,39 +122,39 @@ public:
/// @param context the current context
void saveOasis( KoGenStyle& gs, KoSavingContext& context, bool savingStyle ) const;
- /// Convert an alignment string into an alignment flag (load)
+ /// Convert an tqalignment string into an tqalignment flag (load)
static TQt::AlignmentFlags loadOasisAlignment( const TQCString& str );